exceptiontools.SchemeParserFinishedException
============================================

.. abjad-lineage:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException

.. autoclass:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException.__unicode__
   :noindex:
